Module prelude

Module prelude 

Glob-importable prelude for typical application wiring.

Re-exports

pub use crate::app::App;
pub use crate::command::Command;
pub use crate::command::CommandSpec;
pub use crate::command::BUILTIN_COMMANDS;
pub use crate::features::Feature;
pub use crate::features::Features;
pub use crate::metadata::HelpChannel;
pub use crate::metadata::ReleaseSource;
pub use crate::metadata::ToolMetadata;
pub use crate::version::VersionInfo;
pub use crate::credentials::CredentialProvider;
pub use crate::credentials::NoCredentials;

Structs

CredentialRef
Re-exported from rtb-credentials so downstream tools that implement the v0.4 credentials subtree don’t need to add the credentials crate to their direct dep list. Declarative reference to a credential that the Resolver walks through the documented precedence chain: env > keychain > literal > fallback_env.

Traits

CredentialBearing
Re-exported from rtb-credentials so downstream tools that implement the v0.4 credentials subtree don’t need to add the credentials crate to their direct dep list. Exposes the CredentialRefs in a downstream tool’s config to rtb-cli’s credentials subtree.